==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/vmwarecloudsimple/kotlin/inputs/VirtualNicArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.vmwarecloudsimple.kotlin.inputs

import com.pulumi.azurenative.vmwarecloudsimple.inputs.VirtualNicArgs.builder
import com.pulumi.azurenative.vmwarecloudsimple.kotlin.enums.NICType
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Virtual NIC model
 * @property customization guest OS customization for nic
 * @property ipAddresses NIC ip address
 * @property macAddress NIC MAC address
 * @property network Virtual Network
 * @property nicType NIC type
 * @property powerOnBoot Is NIC powered on/off on boot
 * @property virtualNicId NIC id
 */
public data class VirtualNicArgs(
    public val customization: Output<GuestOSNICCustomizationArgs>? = null,
    public val ipAddresses: Output<List<String>>? = null,
    public val macAddress: Output<String>? = null,
    public val network: Output<VirtualNetworkArgs>,
    public val nicType: Output<NICType>,
    public val powerOnBoot: Output<Boolean>? = null,
    public val virtualNicId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.vmwarecloudsimple.inputs.VirtualNicArgs> {
    override fun toJava(): com.pulumi.azurenative.vmwarecloudsimple.inputs.VirtualNicArgs =
        com.pulumi.azurenative.vmwarecloudsimple.inputs.VirtualNicArgs.builder()
            .customization(customization?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .ipAddresses(ipAddresses?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .macAddress(macAddress?.applyValue({ args0 -> args0 }))
            .network(network.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .nicType(nicType.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .powerOnBoot(powerOnBoot?.applyValue({ args0 -> args0 }))
            .virtualNicId(virtualNicId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualNicArgs].
 */
@PulumiTagMarker
public class VirtualNicArgsBuilder internal constructor() {
    private var customization: Output<GuestOSNICCustomizationArgs>? = null

    private var ipAddresses: Output<List<String>>? = null

    private var macAddress: Output<String>? = null

    private var network: Output<VirtualNetworkArgs>? = null

    private var nicType: Output<NICType>? = null

    private var powerOnBoot: Output<Boolean>? = null

    private var virtualNicId: Output<String>? = null

    /**
     * @param value guest OS customization for nic
     */
    @JvmName("ntqssomtkcfsmgpw")
    public suspend fun customization(`value`: Output<GuestOSNICCustomizationArgs>) {
        this.customization = value
    }

    /**
     * @param value NIC ip address
     */
    @JvmName("xuofkxlkoesvkrts")
    public suspend fun ipAddresses(`value`: Output<List<String>>) {
        this.ipAddresses = value
    }

    @JvmName("hgbvpwsxknlxynvr")
    public suspend fun ipAddresses(vararg values: Output<String>) {
        this.ipAddresses = Output.all(values.asList())
    }

    /**
     * @param values NIC ip address
     */
    @JvmName("erjpjfmkgodqyhgo")
    public suspend fun ipAddresses(values: List<Output<String>>) {
        this.ipAddresses = Output.all(values)
    }

    /**
     * @param value NIC MAC address
     */
    @JvmName("isgjhdtyeryvablj")
    public suspend fun macAddress(`value`: Output<String>) {
        this.macAddress = value
    }

    /**
     * @param value Virtual Network
     */
    @JvmName("coeihlogdbrflaed")
    public suspend fun network(`value`: Output<VirtualNetworkArgs>) {
        this.network = value
    }

    /**
     * @param value NIC type
     */
    @JvmName("ncstvgempilyabiu")
    public suspend fun nicType(`value`: Output<NICType>) {
        this.nicType = value
    }

    /**
     * @param value Is NIC powered on/off on boot
     */
    @JvmName("tdjneqeiylbxmqdm")
    public suspend fun powerOnBoot(`value`: Output<Boolean>) {
        this.powerOnBoot = value
    }

    /**
     * @param value NIC id
     */
    @JvmName("orqlwkemgxcwamti")
    public suspend fun virtualNicId(`value`: Output<String>) {
        this.virtualNicId = value
    }

    /**
     * @param value guest OS customization for nic
     */
    @JvmName("vvqutududifijhvx")
    public suspend fun customization(`value`: GuestOSNICCustomizationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.customization = mapped
    }

    /**
     * @param argument guest OS customization for nic
     */
    @JvmName("egtqocsielioetcx")
    public suspend
    fun customization(argument: suspend GuestOSNICCustomizationArgsBuilder.() -> Unit) {
        val toBeMapped = GuestOSNICCustomizationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.customization = mapped
    }

    /**
     * @param value NIC ip address
     */
    @JvmName("mfbdpctqjubnbbah")
    public suspend fun ipAddresses(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipAddresses = mapped
    }

    /**
     * @param values NIC ip address
     */
    @JvmName("wqoqlyqmlnxntktp")
    public suspend fun ipAddresses(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipAddresses = mapped
    }

    /**
     * @param value NIC MAC address
     */
    @JvmName("ebowhiabbndbxvqe")
    public suspend fun macAddress(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.macAddress = mapped
    }

    /**
     * @param value Virtual Network
     */
    @JvmName("biijsmoqowbyeqhp")
    public suspend fun network(`value`: VirtualNetworkArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.network = mapped
    }

    /**
     * @param argument Virtual Network
     */
    @JvmName("rxfohgcamtvghbxo")
    public suspend fun network(argument: suspend VirtualNetworkArgsBuilder.() -> Unit) {
        val toBeMapped = VirtualNetworkArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.network = mapped
    }

    /**
     * @param value NIC type
     */
    @JvmName("erlotpclhxkjquqa")
    public suspend fun nicType(`value`: NICType) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.nicType = mapped
    }

    /**
     * @param value Is NIC powered on/off on boot
     */
    @JvmName("mcvwujlqujgkdorq")
    public suspend fun powerOnBoot(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.powerOnBoot = mapped
    }

    /**
     * @param value NIC id
     */
    @JvmName("xkpavmjebycdsqsg")
    public suspend fun virtualNicId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.virtualNicId = mapped
    }

    internal fun build(): VirtualNicArgs = VirtualNicArgs(
        customization = customization,
        ipAddresses = ipAddresses,
        macAddress = macAddress,
        network = network ?: throw PulumiNullFieldException("network"),
        nicType = nicType ?: throw PulumiNullFieldException("nicType"),
        powerOnBoot = powerOnBoot,
        virtualNicId = virtualNicId,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/vmwarecloudsimple/kotlin/inputs/VirtualNicArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.vmwarecloudsimple.kotlin.inputs

import com.pulumi.azurenative.vmwarecloudsimple.inputs.VirtualNicArgs.builder
import com.pulumi.azurenative.vmwarecloudsimple.kotlin.enums.NICType
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Virtual NIC model
 * @property customization guest OS customization for nic
 * @property ipAddresses NIC ip address
 * @property macAddress NIC MAC address
 * @property network Virtual Network
 * @property nicType NIC type
 * @property powerOnBoot Is NIC powered on/off on boot
 * @property virtualNicId NIC id
 */
public data class VirtualNicArgs(
    public val customization: Output<GuestOSNICCustomizationArgs>? = null,
    public val ipAddresses: Output<List<String>>? = null,
    public val macAddress: Output<String>? = null,
    public val network: Output<VirtualNetworkArgs>,
    public val nicType: Output<NICType>,
    public val powerOnBoot: Output<Boolean>? = null,
    public val virtualNicId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.vmwarecloudsimple.inputs.VirtualNicArgs> {
    override fun toJava(): com.pulumi.azurenative.vmwarecloudsimple.inputs.VirtualNicArgs =
        com.pulumi.azurenative.vmwarecloudsimple.inputs.VirtualNicArgs.builder()
            .customization(customization?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .ipAddresses(ipAddresses?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .macAddress(macAddress?.applyValue({ args0 -> args0 }))
            .network(network.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .nicType(nicType.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .powerOnBoot(powerOnBoot?.applyValue({ args0 -> args0 }))
            .virtualNicId(virtualNicId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualNicArgs].
 */
@PulumiTagMarker
public class VirtualNicArgsBuilder internal constructor() {
    private var customization: Output<GuestOSNICCustomizationArgs>? = null

    private var ipAddresses: Output<List<String>>? = null

    private var macAddress: Output<String>? = null

    private var network: Output<VirtualNetworkArgs>? = null

    private var nicType: Output<NICType>? = null

    private var powerOnBoot: Output<Boolean>? = null

    private var virtualNicId: Output<String>? = null

    /**
     * @param value guest OS customization for nic
     */
    @JvmName("canvgvpqrdoggaub")
    public suspend fun customization(`value`: Output<GuestOSNICCustomizationArgs>) {
        this.customization = value
    }

    /**
     * @param value NIC ip address
     */
    @JvmName("miibmienfdyjsoqm")
    public suspend fun ipAddresses(`value`: Output<List<String>>) {
        this.ipAddresses = value
    }

    @JvmName("ypxgqckxecbpwdjx")
    public suspend fun ipAddresses(vararg values: Output<String>) {
        this.ipAddresses = Output.all(values.asList())
    }

    /**
     * @param values NIC ip address
     */
    @JvmName("xmxpfpcbsdrnvspj")
    public suspend fun ipAddresses(values: List<Output<String>>) {
        this.ipAddresses = Output.all(values)
    }

    /**
     * @param value NIC MAC address
     */
    @JvmName("itiekerysqbkaxlj")
    public suspend fun macAddress(`value`: Output<String>) {
        this.macAddress = value
    }

    /**
     * @param value Virtual Network
     */
    @JvmName("cgffydccptnyhhbm")
    public suspend fun network(`value`: Output<VirtualNetworkArgs>) {
        this.network = value
    }

    /**
     * @param value NIC type
     */
    @JvmName("whhxomkjckkqpfbm")
    public suspend fun nicType(`value`: Output<NICType>) {
        this.nicType = value
    }

    /**
     * @param value Is NIC powered on/off on boot
     */
    @JvmName("wwcqnnltcdogmrqn")
    public suspend fun powerOnBoot(`value`: Output<Boolean>) {
        this.powerOnBoot = value
    }

    /**
     * @param value NIC id
     */
    @JvmName("iplwdwfxstixvybw")
    public suspend fun virtualNicId(`value`: Output<String>) {
        this.virtualNicId = value
    }

    /**
     * @param value guest OS customization for nic
     */
    @JvmName("fsdowdnpigvtckft")
    public suspend fun customization(`value`: GuestOSNICCustomizationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.customization = mapped
    }

    /**
     * @param argument guest OS customization for nic
     */
    @JvmName("qsbfrypbhuvhfjcn")
    public suspend
    fun customization(argument: suspend GuestOSNICCustomizationArgsBuilder.() -> Unit) {
        val toBeMapped = GuestOSNICCustomizationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.customization = mapped
    }

    /**
     * @param value NIC ip address
     */
    @JvmName("ewxmkbywafvcfqog")
    public suspend fun ipAddresses(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipAddresses = mapped
    }

    /**
     * @param values NIC ip address
     */
    @JvmName("ejaciguukruerkmt")
    public suspend fun ipAddresses(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipAddresses = mapped
    }

    /**
     * @param value NIC MAC address
     */
    @JvmName("evmnkaiwmbewrjct")
    public suspend fun macAddress(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.macAddress = mapped
    }

    /**
     * @param value Virtual Network
     */
    @JvmName("lqcvailaynqbspby")
    public suspend fun network(`value`: VirtualNetworkArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.network = mapped
    }

    /**
     * @param argument Virtual Network
     */
    @JvmName("fbskydasfvhuanto")
    public suspend fun network(argument: suspend VirtualNetworkArgsBuilder.() -> Unit) {
        val toBeMapped = VirtualNetworkArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.network = mapped
    }

    /**
     * @param value NIC type
     */
    @JvmName("rujidvovwkphqxcb")
    public suspend fun nicType(`value`: NICType) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.nicType = mapped
    }

    /**
     * @param value Is NIC powered on/off on boot
     */
    @JvmName("csyoulanblcdrinh")
    public suspend fun powerOnBoot(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.powerOnBoot = mapped
    }

    /**
     * @param value NIC id
     */
    @JvmName("fybblqjcpdrxcrmi")
    public suspend fun virtualNicId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.virtualNicId = mapped
    }

    internal fun build(): VirtualNicArgs = VirtualNicArgs(
        customization = customization,
        ipAddresses = ipAddresses,
        macAddress = macAddress,
        network = network ?: throw PulumiNullFieldException("network"),
        nicType = nicType ?: throw PulumiNullFieldException("nicType"),
        powerOnBoot = powerOnBoot,
        virtualNicId = virtualNicId,
    )
}
